Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(194)

Unified Diff: webrtc/base/messagehandler.h

Issue 1797463002: Make rtc::scoped_ptr a type alias for std::unique_ptr (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@master
Patch Set: Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | webrtc/base/scoped_ptr.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/base/messagehandler.h
diff --git a/webrtc/base/messagehandler.h b/webrtc/base/messagehandler.h
index b55b229a6db4792dca32ca95c0adaff508c7110d..90563e4083993cf1333f9190304d078822f54675 100644
--- a/webrtc/base/messagehandler.h
+++ b/webrtc/base/messagehandler.h
@@ -50,18 +50,18 @@ class FunctorMessageHandler : public MessageHandler {
ReturnT result_;
};
// Specialization for rtc::scoped_ptr<ReturnT>.
template <class ReturnT, class FunctorT>
-class FunctorMessageHandler<class rtc::scoped_ptr<ReturnT>, FunctorT>
+class FunctorMessageHandler<class std::unique_ptr<ReturnT>, FunctorT>
: public MessageHandler {
public:
explicit FunctorMessageHandler(const FunctorT& functor) : functor_(functor) {}
virtual void OnMessage(Message* msg) { result_ = std::move(functor_()); }
- rtc::scoped_ptr<ReturnT> result() { return std::move(result_); }
+ std::unique_ptr<ReturnT> result() { return std::move(result_); }
private:
FunctorT functor_;
- rtc::scoped_ptr<ReturnT> result_;
+ std::unique_ptr<ReturnT> result_;
};
// Specialization for ReturnT of void.
« no previous file with comments | « no previous file | webrtc/base/scoped_ptr.h » ('j') | no next file with comments »
@@ -50,18 +50,18 @@ class FunctorMessageHandler : public MessageHandler {
ReturnT result_;
};
-// Specialization for rtc::scoped_ptr<ReturnT>.
+// Specialization for std::unique_ptr<ReturnT>.
template <class ReturnT, class FunctorT>

Powered by Google App Engine
This is Rietveld 408576698